@@ -2,13 +2,17 @@ import yaml
 from termcolor import colored
 
 from common_structure_microservices.exception import GenericMicroserviceError
+from common_structure_microservices.utilities import Constants
 
 
 class Profiles:
     file_config = yaml.load(open('profile.yaml'), Loader=yaml.FullLoader)['django']
     APP_NAME = file_config['application']['name']
     PROFILE = file_config['profiles']['active']
-    ENVIRONMENTS = f'.environments/{APP_NAME}-{PROFILE}.yml'
+    if PROFILE == Constants.DEVELOP:
+        ENVIRONMENTS = f'.environments/asn_{PROFILE}.yml'
+    else:
+        ENVIRONMENTS = f'.environments/{APP_NAME}_{PROFILE}.yml'
     APPLICATION = file_config['application']
     CONFIG = {}
     env = {}
