@@ -47,7 +47,7 @@ class Constants:
     REFRESH_TOKEN = 'REFRESH_TOKEN'
     ACCESS_TOKEN = 'ACCESS_TOKEN'
     PHOTO_DEFAULT = '3fa85f64-5717-4562-b3fc-2c963f66afa6'
-    FRONTEND_CONTEXT = 'davinci'
+    FRONTEND_CONTEXT = 'joinufps'
     WINDOWS = 'win'
     LINUX = 'linux'
     MACOS = 'mac'
